/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __GF_NAUTILUS_GEN_H__
#define __GF_NAUTILUS_GEN_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Nautilus.FileOperations */

#define GF_TYPE_NAUTILUS_GEN (gf_nautilus_gen_get_type ())
#define GF_NAUTILUS_GEN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GF_TYPE_NAUTILUS_GEN, GfNautilusGen))
#define GF_IS_NAUTILUS_GEN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GF_TYPE_NAUTILUS_GEN))
#define GF_NAUTILUS_GEN_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), GF_TYPE_NAUTILUS_GEN, GfNautilusGenIface))

struct _GfNautilusGen;
typedef struct _GfNautilusGen GfNautilusGen;
typedef struct _GfNautilusGenIface GfNautilusGenIface;

struct _GfNautilusGenIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_copy_uris) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *arg_SourceFilesURIList,
    const gchar *arg_DestinationDirectoryURI);

  gboolean (*handle_create_folder) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_URI);

  gboolean (*handle_empty_trash) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_move_uris) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *arg_SourceFilesURIList,
    const gchar *arg_DestinationDirectoryURI);

  gboolean (*handle_redo) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_rename_file) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_URI,
    const gchar *arg_NewName);

  gboolean (*handle_trash_files) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *arg_URIs);

  gboolean (*handle_undo) (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

  gint  (*get_undo_status) (GfNautilusGen *object);

};

GType gf_nautilus_gen_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *gf_nautilus_gen_interface_info (void);
guint gf_nautilus_gen_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void gf_nautilus_gen_complete_copy_uris (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_move_uris (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_empty_trash (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_trash_files (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_create_folder (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_rename_file (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_undo (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);

void gf_nautilus_gen_complete_redo (
    GfNautilusGen *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void gf_nautilus_gen_call_copy_uris (
    GfNautilusGen *proxy,
    const gchar *const *arg_SourceFilesURIList,
    const gchar *arg_DestinationDirectoryURI,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_copy_uris_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_copy_uris_sync (
    GfNautilusGen *proxy,
    const gchar *const *arg_SourceFilesURIList,
    const gchar *arg_DestinationDirectoryURI,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_move_uris (
    GfNautilusGen *proxy,
    const gchar *const *arg_SourceFilesURIList,
    const gchar *arg_DestinationDirectoryURI,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_move_uris_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_move_uris_sync (
    GfNautilusGen *proxy,
    const gchar *const *arg_SourceFilesURIList,
    const gchar *arg_DestinationDirectoryURI,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_empty_trash (
    GfNautilusGen *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_empty_trash_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_empty_trash_sync (
    GfNautilusGen *proxy,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_trash_files (
    GfNautilusGen *proxy,
    const gchar *const *arg_URIs,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_trash_files_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_trash_files_sync (
    GfNautilusGen *proxy,
    const gchar *const *arg_URIs,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_create_folder (
    GfNautilusGen *proxy,
    const gchar *arg_URI,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_create_folder_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_create_folder_sync (
    GfNautilusGen *proxy,
    const gchar *arg_URI,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_rename_file (
    GfNautilusGen *proxy,
    const gchar *arg_URI,
    const gchar *arg_NewName,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_rename_file_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_rename_file_sync (
    GfNautilusGen *proxy,
    const gchar *arg_URI,
    const gchar *arg_NewName,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_undo (
    GfNautilusGen *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_undo_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_undo_sync (
    GfNautilusGen *proxy,
    GCancellable *cancellable,
    GError **error);

void gf_nautilus_gen_call_redo (
    GfNautilusGen *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean gf_nautilus_gen_call_redo_finish (
    GfNautilusGen *proxy,
    GAsyncResult *res,
    GError **error);

gboolean gf_nautilus_gen_call_redo_sync (
    GfNautilusGen *proxy,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gint gf_nautilus_gen_get_undo_status (GfNautilusGen *object);
void gf_nautilus_gen_set_undo_status (GfNautilusGen *object, gint value);


/* ---- */

#define GF_TYPE_NAUTILUS_GEN_PROXY (gf_nautilus_gen_proxy_get_type ())
#define GF_NAUTILUS_GEN_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GF_TYPE_NAUTILUS_GEN_PROXY, GfNautilusGenProxy))
#define GF_NAUTILUS_GEN_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), GF_TYPE_NAUTILUS_GEN_PROXY, GfNautilusGenProxyClass))
#define GF_NAUTILUS_GEN_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GF_TYPE_NAUTILUS_GEN_PROXY, GfNautilusGenProxyClass))
#define GF_IS_NAUTILUS_GEN_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GF_TYPE_NAUTILUS_GEN_PROXY))
#define GF_IS_NAUTILUS_GEN_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GF_TYPE_NAUTILUS_GEN_PROXY))

typedef struct _GfNautilusGenProxy GfNautilusGenProxy;
typedef struct _GfNautilusGenProxyClass GfNautilusGenProxyClass;
typedef struct _GfNautilusGenProxyPrivate GfNautilusGenProxyPrivate;

struct _GfNautilusGenProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  GfNautilusGenProxyPrivate *priv;
};

struct _GfNautilusGenProxyClass
{
  GDBusProxyClass parent_class;
};

GType gf_nautilus_gen_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GfNautilusGenProxy, g_object_unref)
#endif

void gf_nautilus_gen_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
GfNautilusGen *gf_nautilus_gen_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
GfNautilusGen *gf_nautilus_gen_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void gf_nautilus_gen_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
GfNautilusGen *gf_nautilus_gen_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
GfNautilusGen *gf_nautilus_gen_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define GF_TYPE_NAUTILUS_GEN_SKELETON (gf_nautilus_gen_skeleton_get_type ())
#define GF_NAUTILUS_GEN_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GF_TYPE_NAUTILUS_GEN_SKELETON, GfNautilusGenSkeleton))
#define GF_NAUTILUS_GEN_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), GF_TYPE_NAUTILUS_GEN_SKELETON, GfNautilusGenSkeletonClass))
#define GF_NAUTILUS_GEN_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GF_TYPE_NAUTILUS_GEN_SKELETON, GfNautilusGenSkeletonClass))
#define GF_IS_NAUTILUS_GEN_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GF_TYPE_NAUTILUS_GEN_SKELETON))
#define GF_IS_NAUTILUS_GEN_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GF_TYPE_NAUTILUS_GEN_SKELETON))

typedef struct _GfNautilusGenSkeleton GfNautilusGenSkeleton;
typedef struct _GfNautilusGenSkeletonClass GfNautilusGenSkeletonClass;
typedef struct _GfNautilusGenSkeletonPrivate GfNautilusGenSkeletonPrivate;

struct _GfNautilusGenSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  GfNautilusGenSkeletonPrivate *priv;
};

struct _GfNautilusGenSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType gf_nautilus_gen_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GfNautilusGenSkeleton, g_object_unref)
#endif

GfNautilusGen *gf_nautilus_gen_skeleton_new (void);


G_END_DECLS

#endif /* __GF_NAUTILUS_GEN_H__ */
