/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __GF_LOGIN_SEAT_GEN_H__
#define __GF_LOGIN_SEAT_GEN_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.login1.Seat */

#define GF_TYPE_LOGIN_SEAT_GEN (gf_login_seat_gen_get_type ())
#define GF_LOGIN_SEAT_GEN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GF_TYPE_LOGIN_SEAT_GEN, GfLoginSeatGen))
#define GF_IS_LOGIN_SEAT_GEN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GF_TYPE_LOGIN_SEAT_GEN))
#define GF_LOGIN_SEAT_GEN_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), GF_TYPE_LOGIN_SEAT_GEN, GfLoginSeatGenIface))

struct _GfLoginSeatGen;
typedef struct _GfLoginSeatGen GfLoginSeatGen;
typedef struct _GfLoginSeatGenIface GfLoginSeatGenIface;

struct _GfLoginSeatGenIface
{
  GTypeInterface parent_iface;

  gboolean  (*get_can_multi_session) (GfLoginSeatGen *object);

};

GType gf_login_seat_gen_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *gf_login_seat_gen_interface_info (void);
guint gf_login_seat_gen_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus property accessors: */
gboolean gf_login_seat_gen_get_can_multi_session (GfLoginSeatGen *object);
void gf_login_seat_gen_set_can_multi_session (GfLoginSeatGen *object, gboolean value);


/* ---- */

#define GF_TYPE_LOGIN_SEAT_GEN_PROXY (gf_login_seat_gen_proxy_get_type ())
#define GF_LOGIN_SEAT_GEN_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GF_TYPE_LOGIN_SEAT_GEN_PROXY, GfLoginSeatGenProxy))
#define GF_LOGIN_SEAT_GEN_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), GF_TYPE_LOGIN_SEAT_GEN_PROXY, GfLoginSeatGenProxyClass))
#define GF_LOGIN_SEAT_GEN_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GF_TYPE_LOGIN_SEAT_GEN_PROXY, GfLoginSeatGenProxyClass))
#define GF_IS_LOGIN_SEAT_GEN_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GF_TYPE_LOGIN_SEAT_GEN_PROXY))
#define GF_IS_LOGIN_SEAT_GEN_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GF_TYPE_LOGIN_SEAT_GEN_PROXY))

typedef struct _GfLoginSeatGenProxy GfLoginSeatGenProxy;
typedef struct _GfLoginSeatGenProxyClass GfLoginSeatGenProxyClass;
typedef struct _GfLoginSeatGenProxyPrivate GfLoginSeatGenProxyPrivate;

struct _GfLoginSeatGenProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  GfLoginSeatGenProxyPrivate *priv;
};

struct _GfLoginSeatGenProxyClass
{
  GDBusProxyClass parent_class;
};

GType gf_login_seat_gen_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GfLoginSeatGenProxy, g_object_unref)
#endif

void gf_login_seat_gen_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
GfLoginSeatGen *gf_login_seat_gen_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
GfLoginSeatGen *gf_login_seat_gen_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void gf_login_seat_gen_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
GfLoginSeatGen *gf_login_seat_gen_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
GfLoginSeatGen *gf_login_seat_gen_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define GF_TYPE_LOGIN_SEAT_GEN_SKELETON (gf_login_seat_gen_skeleton_get_type ())
#define GF_LOGIN_SEAT_GEN_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GF_TYPE_LOGIN_SEAT_GEN_SKELETON, GfLoginSeatGenSkeleton))
#define GF_LOGIN_SEAT_GEN_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), GF_TYPE_LOGIN_SEAT_GEN_SKELETON, GfLoginSeatGenSkeletonClass))
#define GF_LOGIN_SEAT_GEN_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GF_TYPE_LOGIN_SEAT_GEN_SKELETON, GfLoginSeatGenSkeletonClass))
#define GF_IS_LOGIN_SEAT_GEN_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GF_TYPE_LOGIN_SEAT_GEN_SKELETON))
#define GF_IS_LOGIN_SEAT_GEN_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GF_TYPE_LOGIN_SEAT_GEN_SKELETON))

typedef struct _GfLoginSeatGenSkeleton GfLoginSeatGenSkeleton;
typedef struct _GfLoginSeatGenSkeletonClass GfLoginSeatGenSkeletonClass;
typedef struct _GfLoginSeatGenSkeletonPrivate GfLoginSeatGenSkeletonPrivate;

struct _GfLoginSeatGenSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  GfLoginSeatGenSkeletonPrivate *priv;
};

struct _GfLoginSeatGenSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType gf_login_seat_gen_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GfLoginSeatGenSkeleton, g_object_unref)
#endif

GfLoginSeatGen *gf_login_seat_gen_skeleton_new (void);


G_END_DECLS

#endif /* __GF_LOGIN_SEAT_GEN_H__ */
